import QtQuick 2.9
import QtQuick.Controls 2.2
import QtQuick.Window 2.2
import MuseScore 3.0

MuseScore {
    menuPath:"Plugins.    Bayankeyboard"
    version:  "0.3.0"
    description: "Noten omzetten naar Griffschrift"
    requiresScore: false

    pluginType: "dock"
    dockArea: "bottom"
    
    implicitWidth:  200
    implicitHeight: 700
     
    function findSegment(e) {
        while (e && e.type != Element.SEGMENT)
            e = e.parent;
        return e;
    }
    
    function findSelectedChord() {
        if (!curScore)
            return null;

        var selectedElements = curScore.selection.elements;
        for (var i = 0; i < selectedElements.length; ++i) {
            var e = selectedElements[i];
            if (e.type == Element.NOTE) {
                var chord = e.parent;

                // HACK
                // removeElement(chord) may leave the chord selected,
                // so ensure this chord is really bound to a segment
                // or another chord as a grace note.
                var seg = findSegment(chord);
                var realChord = seg.elementAt(chord.track);

                if (!realChord || realChord.type != Element.CHORD)
                    return null;

                if (chord.is(realChord))
                    return chord;

                var grace = realChord.graceNotes;
                for (var i = 0; i < grace.length; ++i) {
                    if (grace[i].is(chord))
                        return chord;
                }

                return null;
            }
        }
    }

    function toggleNote(pitch) {
        if (!curScore)
            return;

        var chord = findSelectedChord();
        var existingNote = null;

        if (chord) {
            var chordNotes = chord.notes;

            for (var i = 0; i < chordNotes.length; ++i) {
                var chordNote = chordNotes[i];
                if (chordNote.pitch == pitch) {
                    existingNote = chordNote;
                    break;
                }
            }
        }
             

        curScore.startCmd();

        if (existingNote) {
            removeElement(existingNote);
        } else {
            var cursor = curScore.newCursor();
            cursor.inputStateMode = Cursor.INPUT_STATE_SYNC_WITH_SCORE;

            var addToChord = (chord != null);
            cursor.addNote(pitch, addToChord);

            cursor.prev(); // return cursor to the chord's position
        }

        curScore.endCmd();
    }

    Row {
        spacing: 10
        leftPadding: 10
         Text {
            font.pixelSize: 13
            fontSizeMode: Text.Fit
            text:
                 "                    "     }

        

        Rectangle {
            width: 1000
            height: 220
            color: "lightgrey"

                Text {
                id: notenText
                anchors.horizontalCenter: parent.horizontalCenter
                font.pixelSize: 30
                fontSizeMode: Text.Fit
                text: "Bayan Keyboard"
            }
            
            
           
            Column {
                anchors.top: notenText.bottom
                leftPadding: 10

                spacing: 2 // determines spacing between rows

                

                 BayanButtonRow {
                    leftPadding: 35
                    rowText: ""

                    model: ListModel {
                        ListElement { color: "white"; text: "A2"; pitch: 45 }
                        ListElement { color: "white"; text: "C3"; pitch: 48 }
                        ListElement { color: "grey"; text: "Eb3"; pitch: 51 }
                        ListElement { color: "grey"; text: "f#3"; pitch: 54 }
                        ListElement { color: "white"; text: "A3"; pitch: 57 }
                        ListElement { color: "white"; text: "C4"; pitch: 60 }
                        ListElement { color: "grey"; text: "Eb4"; pitch: 63 }
                        ListElement { color: "grey"; text: "f#4"; pitch: 66 }
                        ListElement { color: "white"; text: "A4"; pitch: 69 }
                        ListElement { color: "white"; text: "C5"; pitch: 72 }
                        ListElement { color: "grey"; text: "Eb5"; pitch: 75 }
                        ListElement { color: "grey"; text: "f#5"; pitch: 78 }
                        ListElement { color: "white"; text: "A5"; pitch: 81 }
                        ListElement { color: "white"; text: "C6"; pitch: 84 }
                        ListElement { color: "grey"; text: "Eb6"; pitch: 87 }
                        ListElement { color: "grey"; text: "f#6"; pitch: 90 }
                    }

                    onButtonClicked: toggleNote(pitch)
                }

                BayanButtonRow {
                    leftPadding: 0
                    rowText: ""

                    model: ListModel {
                        ListElement { color: "white"; text: "G2"; pitch: 43 }
                        ListElement { color: "grey"; text: "A#2"; pitch: 46 }
                        ListElement { color: "grey"; text: "C#3"; pitch: 49 }
                        ListElement { color: "white"; text: "E3"; pitch: 52 }
                        ListElement { color: "white"; text: "G3"; pitch: 55 }
                        ListElement { color: "grey"; text: "A#3"; pitch: 58 }
                        ListElement { color: "grey"; text: "C#4"; pitch: 61 }
                        ListElement { color: "white"; text: "E4"; pitch: 64 }
                        ListElement { color: "white"; text: "G4"; pitch: 67 }
                        ListElement { color: "grey"; text: "A#4"; pitch: 70 }
                        ListElement { color: "grey"; text: "C#5"; pitch: 73 }
                        ListElement { color: "white"; text: "E5"; pitch: 76 }
                        ListElement { color: "white"; text: "G5"; pitch: 79 }
                        ListElement { color: "grey"; text: "A#5"; pitch: 82 }
                        ListElement { color: "grey"; text: "C#6"; pitch: 85 }
                        ListElement { color: "white"; text: "E6"; pitch: 88 }
                        ListElement { color: "white"; text: "G6"; pitch: 91 }
                    }

                    onButtonClicked: toggleNote(pitch)
               
                }
                 
                   BayanButtonRow {
                    leftPadding: 25
                    rowText: ""

                    model: ListModel {
                        ListElement { color: "grey"; text: "G#2"; pitch: 44 }
                        ListElement { color: "white"; text: "B2"; pitch: 47 }
                        ListElement { color: "white"; text: "D3"; pitch: 50 }
                        ListElement { color: "white"; text: "F3"; pitch: 53 }
                        ListElement { color: "grey"; text: "G#3"; pitch: 56 }
                        ListElement { color: "white"; text: "B3"; pitch: 59 }
                        ListElement { color: "white"; text: "D4"; pitch: 62 }
                        ListElement { color: "white"; text: "F4"; pitch: 65 }
                        ListElement { color: "grey"; text: "G#4"; pitch: 68 }
                        ListElement { color: "white"; text: "B4"; pitch: 71 }
                        ListElement { color: "white"; text: "D5"; pitch: 74 }
                        ListElement { color: "white"; text: "F5"; pitch: 77 }
                        ListElement { color: "grey"; text: "G#5"; pitch: 80 }
                        ListElement { color: "white"; text: "B5"; pitch: 83 }
                        ListElement { color: "white"; text: "D6"; pitch: 86 }
                        ListElement { color: "white"; text: "F6"; pitch: 89 }
                     }

                    onButtonClicked: toggleNote(pitch)
                }
              
               
              }   
            }
          }   
        }  
        

